==> seed7_05_20080707.tgz: seed7/src/arr_rtl.h <==
/********************************************************************/
/*                                                                  */
/*  arr_rtl.h     Primitive actions for the array type.             */
/*  Copyright (C) 1989 - 2006  Thomas Mertes                        */
/*                                                                  */
/*  This file is part of the Seed7 Runtime Library.                 */
/*                                                                  */
/*  The Seed7 Runtime Library is free software; you can             */
/*  redistribute it and/or modify it under the terms of the GNU     */
/*  Lesser General Public License as published by the Free Software */
/*  Foundation; either version 2.1 of the License, or (at your      */
/*  option) any later version.                                      */
/*                                                                  */
/*  The Seed7 Runtime Library is distributed in the hope that it    */
/*  will be useful, but WITHOUT ANY WARRANTY; without even the      */
/*  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR */
/*  PURPOSE.  See the GNU Lesser General Public License for more    */
/*  details.                                                        */
/*                                                                  */
/*  You should have received a copy of the GNU Lesser General       */
/*  Public License along with this program; if not, write to the    */
/*  Free Software Foundation, Inc., 51 Franklin Street,             */
/*  Fifth Floor, Boston, MA  02110-1301, USA.                       */
/*                                                                  */
/*  Module: Seed7 Runtime Library                                   */
/*  File: seed7/src/arr_rtl.h                                       */
/*  Changes: 1991, 1992, 1993, 1994, 2005, 2006  Thomas Mertes      */
/*  Content: Primitive actions for the array type.                  */
/*                                                                  */
/********************************************************************/

#ifdef ANSI_C

void arrAppend (rtlArraytype *, rtlArraytype);
rtlArraytype arrArrlit (rtlArraytype);
rtlArraytype arrArrlit2 (inttype, rtlArraytype);
rtlArraytype arrBaselit (rtlObjecttype);
rtlArraytype arrBaselit2 (inttype, rtlObjecttype);
rtlArraytype arrCat (rtlArraytype, rtlArraytype);
rtlArraytype arrExtend (rtlArraytype, rtlObjecttype);
rtlArraytype arrGen (rtlObjecttype, rtlObjecttype);
rtlArraytype arrHead (rtlArraytype, inttype);
rtlArraytype arrRange (rtlArraytype, inttype, inttype);
rtlGenerictype arrRemove (rtlArraytype *, inttype);
rtlArraytype arrSort (rtlArraytype, inttype (rtlGenerictype, rtlGenerictype));
rtlArraytype arrTail (rtlArraytype, inttype);

#else

void arrAppend ();
rtlArraytype arrArrlit ();
rtlArraytype arrArrlit2 ();
rtlArraytype arrBaselit ();
rtlArraytype arrBaselit2 ();
rtlArraytype arrCat ();
rtlArraytype arrExtend ();
rtlArraytype arrGen ();
rtlArraytype arrHead ();
rtlArraytype arrRange ();
rtlGenerictype arrRemove ();
rtlArraytype arrSort ();
rtlArraytype arrTail ();

#endif

==> seed7_05_20090413.tgz: seed7/src/arr_rtl.h <==
/********************************************************************/
/*                                                                  */
/*  arr_rtl.h     Primitive actions for the array type.             */
/*  Copyright (C) 1989 - 2006  Thomas Mertes                        */
/*                                                                  */
/*  This file is part of the Seed7 Runtime Library.                 */
/*                                                                  */
/*  The Seed7 Runtime Library is free software; you can             */
/*  redistribute it and/or modify it under the terms of the GNU     */
/*  Lesser General Public License as published by the Free Software */
/*  Foundation; either version 2.1 of the License, or (at your      */
/*  option) any later version.                                      */
/*                                                                  */
/*  The Seed7 Runtime Library is distributed in the hope that it    */
/*  will be useful, but WITHOUT ANY WARRANTY; without even the      */
/*  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR */
/*  PURPOSE.  See the GNU Lesser General Public License for more    */
/*  details.                                                        */
/*                                                                  */
/*  You should have received a copy of the GNU Lesser General       */
/*  Public License along with this program; if not, write to the    */
/*  Free Software Foundation, Inc., 51 Franklin Street,             */
/*  Fifth Floor, Boston, MA  02110-1301, USA.                       */
/*                                                                  */
/*  Module: Seed7 Runtime Library                                   */
/*  File: seed7/src/arr_rtl.h                                       */
/*  Changes: 1991, 1992, 1993, 1994, 2005, 2006  Thomas Mertes      */
/*  Content: Primitive actions for the array type.                  */
/*                                                                  */
/********************************************************************/

#ifdef ANSI_C

void arrAppend (rtlArraytype *arr_variable, rtlArraytype arr_from);
rtlArraytype arrArrlit (rtlArraytype arr1);
rtlArraytype arrArrlit2 (inttype start_position, rtlArraytype arr1);
rtlArraytype arrBaselit (rtlObjecttype element);
rtlArraytype arrBaselit2 (inttype start_position, rtlObjecttype element);
rtlArraytype arrCat (rtlArraytype arr1, rtlArraytype arr2);
rtlArraytype arrExtend (rtlArraytype arr1, rtlObjecttype element);
rtlArraytype arrGen (rtlObjecttype element1, rtlObjecttype element2);
rtlArraytype arrHead (rtlArraytype arr1, inttype stop);
rtlArraytype arrRange (rtlArraytype arr1, inttype start, inttype stop);
rtlGenerictype arrRemove (rtlArraytype *arr_to, inttype position);
rtlArraytype arrSort (rtlArraytype arr1, inttype cmp_func (rtlGenerictype, rtlGenerictype));
rtlArraytype arrTail (rtlArraytype arr1, inttype start);

#else

void arrAppend ();
rtlArraytype arrArrlit ();
rtlArraytype arrArrlit2 ();
rtlArraytype arrBaselit ();
rtlArraytype arrBaselit2 ();
rtlArraytype arrCat ();
rtlArraytype arrExtend ();
rtlArraytype arrGen ();
rtlArraytype arrHead ();
rtlArraytype arrRange ();
rtlGenerictype arrRemove ();
rtlArraytype arrSort ();
rtlArraytype arrTail ();

#endif
